@@ -1,8 +1,7 @@
 #ifndef GSF_BLOB_H
 #define GSF_BLOB_H
 
-#include <gsf/gsf.h>
-#include <glib-object.h>
+#include <gsf/gsf-fwd.h>
 
 G_BEGIN_DECLS
 
@@ -16,7 +15,6 @@ G_BEGIN_DECLS
 /* Deprecated old typo */
 #define GSF_TYPE_BLOB			(gsf_blob_get_type ())
 
-typedef struct _GsfBlob GsfBlob;
 typedef struct _GsfBlobClass GsfBlobClass;
 typedef struct _GsfBlobPrivate GsfBlobPrivate;
 
@@ -25,7 +23,7 @@ struct _GsfBlob {
 	GsfBlobPrivate *priv;
 };
 
-GType gsf_blob_get_type (void) G_GNUC_CONST;
+GType gsf_blob_get_type (void);
 /* void  gsf_blob_register_type (GTypeModule *module); glib dynamic types are not thread safe */
 
 GsfBlob *gsf_blob_new (gsize size,
