@@ -19,11 +19,11 @@
  * USA
  */
 
-#include "gsf-config.h"
+#include <gsf-config.h>
+#include <gsf/gsf-clip-data.h>
+#include <gsf/gsf.h>
+
 #include <glib/gi18n-lib.h>
-#include "gsf-clip-data.h"
-#include "gsf-utils.h"
-#include "gsf-impl-utils.h"
 
 /**
  * GsfClipFormatWindows:
@@ -81,7 +81,7 @@ gsf_clip_data_class_init (GObjectClass *gobject_class)
 
 GSF_CLASS (GsfClipData, gsf_clip_data,
 	   gsf_clip_data_class_init, gsf_clip_data_init,
-	   G_TYPE_OBJECT);
+	   G_TYPE_OBJECT)
 
 /**
  * gsf_clip_data_new:
@@ -103,7 +103,6 @@ gsf_clip_data_new (GsfClipFormat format, GsfBlob *data_blob)
 	g_return_val_if_fail (GSF_IS_BLOB (data_blob), NULL);
 
 	clip_data = g_object_new (GSF_TYPE_CLIP_DATA, NULL);
-	if (G_UNLIKELY (NULL == clip_data)) return NULL;
 
 	priv = clip_data->priv;
 
