@@ -51,7 +51,7 @@ typedef struct {
  *
  * <note>This adds a reference to @source.</note>
  *
- * Returns: a new file or %NULL.
+ * Returns: (nullable): a new file
  **/
 GsfInput *
 gsf_input_textline_new (GsfInput *source)
@@ -94,6 +94,7 @@ gsf_input_textline_dup (GsfInput *src_input, G_GNUC_UNUSED GError **err)
 
 	dst->source = g_object_ref (src->source);
 	gsf_input_set_size (GSF_INPUT (dst), gsf_input_size (src_input));
+	gsf_input_set_name (GSF_INPUT (dst), gsf_input_name (src_input));
 
 	return GSF_INPUT (dst);
 }
@@ -102,16 +103,26 @@ static guint8 const *
 gsf_input_textline_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 {
 	GsfInputTextline *textline = GSF_INPUT_TEXTLINE (input);
+	const guint8 *res;
+
 	textline->remainder = NULL;
-	return gsf_input_read (textline->source, num_bytes, buffer);
+	res = gsf_input_read (textline->source, num_bytes, buffer);
+	input->cur_offset = textline->source->cur_offset;
+
+	return res;
 }
 
 static gboolean
 gsf_input_textline_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 {
 	GsfInputTextline *textline = GSF_INPUT_TEXTLINE (input);
+	gboolean res;
+
 	textline->remainder = NULL;
-	return gsf_input_seek (textline->source, offset, whence);
+	res = gsf_input_seek (textline->source, offset, whence);
+	input->cur_offset = textline->source->cur_offset;
+
+	return res;
 }
 
 static void
@@ -152,7 +163,7 @@ GSF_CLASS (GsfInputTextline, gsf_input_textline,
  * Trailing newlines and carriage returns are stripped, and the resultant buffer
  * can be edited.
  *
- * Returns: (transfer none): the string read, or %NULL on eof.
+ * Returns: (array) (transfer none) (nullable): the string read, or %NULL on eof.
  **/
 unsigned char *
 gsf_input_textline_ascii_gets (GsfInputTextline *textline)
@@ -168,7 +179,7 @@ gsf_input_textline_ascii_gets (GsfInputTextline *textline)
  * Trailing newlines and carriage returns are stripped, and the resultant buffer
  * can be edited.
  *
- * Returns: (transfer none): the string read, or %NULL on eof.
+ * Returns: (array) (transfer none) (nullable): the string read, or %NULL on eof.
  **/
 guint8 *
 gsf_input_textline_utf8_gets (GsfInputTextline *textline)
@@ -234,12 +245,14 @@ gsf_input_textline_utf8_gets (GsfInputTextline *textline)
 			break;
 		} else
 			textline->remainder = NULL;
-
 	}
 
 	textline->remainder = ptr;
 	textline->remainder_size = end - ptr;
 
+	GSF_INPUT(textline)->cur_offset = textline->source->cur_offset -
+		(textline->remainder ? textline->remainder_size : 0);
+
 	textline->buf[count] = '\0';
 	return textline->buf;
 }
