@@ -283,13 +283,14 @@ static guint64
 datetime_to_filetime (GDateTime *dt)
 {
 	static const guint64 epoch = G_GINT64_CONSTANT (11644473600);
-	GTimeVal tv;
+
 	if (!dt)
 		return 0u;
 
 	/* ft is number of 100ns since Jan 1 1601 */
-	g_date_time_to_timeval (dt, &tv);
-	return (tv.tv_sec + epoch) * 10000000u + tv.tv_usec * 10u;
+
+	return (g_date_time_to_unix(dt) + epoch) * 10000000u
+		+ g_date_time_get_microsecond(dt) * 10u;
 }
 
 static void
@@ -802,7 +803,7 @@ gsf_outfile_msole_class_init (GObjectClass *gobject_class)
 				      _("Sink"),
 				      _("The destination for writes"),
 				      GSF_OUTPUT_TYPE,
-				      GSF_PARAM_STATIC |
+				      G_PARAM_STATIC_STRINGS |
 				      G_PARAM_READWRITE |
 				      G_PARAM_CONSTRUCT_ONLY));
 
@@ -814,7 +815,7 @@ gsf_outfile_msole_class_init (GObjectClass *gobject_class)
 				    _("The size of the OLE's small blocks"),
 				    8u, ZERO_PAD_BUF_SIZE,
 				    OLE_DEFAULT_SB_SIZE,
-				    GSF_PARAM_STATIC |
+				    G_PARAM_STATIC_STRINGS |
 				    G_PARAM_READWRITE |
 				    G_PARAM_CONSTRUCT_ONLY));
 
@@ -826,7 +827,7 @@ gsf_outfile_msole_class_init (GObjectClass *gobject_class)
 				    _("The size of the OLE's big blocks"),
 				    DIRENT_SIZE, ZERO_PAD_BUF_SIZE,
 				    OLE_DEFAULT_BB_SIZE,
-				    GSF_PARAM_STATIC |
+				    G_PARAM_STATIC_STRINGS |
 				    G_PARAM_READWRITE |
 				    G_PARAM_CONSTRUCT_ONLY));
 
