@@ -25,6 +25,7 @@
 #include <gsf/gsf.h>
 #include <gsf/gsf-zip-impl.h>
 #include <glib/gi18n-lib.h>
+#include "gsf-priv.h"
 
 #include <string.h>
 #include <time.h>
@@ -300,7 +301,7 @@ zip_trailer64_write (GsfOutfileZip *zip, unsigned entries,
 
 	memset (buf, 0, sizeof buf);
 	GSF_LE_SET_GUINT32 (buf, ZIP_TRAILER64_SIGNATURE);
-	GSF_LE_SET_GUINT64 (buf + ZIP_TRAILER64_RECSIZE, sizeof buf);
+	GSF_LE_SET_GUINT64 (buf + ZIP_TRAILER64_RECSIZE, sizeof buf - 12);
 	GSF_LE_SET_GUINT16 (buf + ZIP_TRAILER64_ENCODER,
 			    (ZIP_OS_UNIX << 8) + extract);
 	GSF_LE_SET_GUINT16 (buf + ZIP_TRAILER64_EXTRACT,
@@ -911,33 +912,40 @@ gsf_outfile_zip_new_child (GsfOutfile *parent,
 	GsfOutfileZip *zip_parent = (GsfOutfileZip *)parent;
 	GsfOutfileZip *child;
 	size_t n_params = 0;
-	GParameter *params = NULL;
+	GsfParam *params = NULL;
 	char *display_name;
+	const char **names;
+	GValue *values;
 
 	g_return_val_if_fail (zip_parent != NULL, NULL);
 	g_return_val_if_fail (zip_parent->vdir, NULL);
 	g_return_val_if_fail (zip_parent->vdir->is_directory, NULL);
 	g_return_val_if_fail (name && *name, NULL);
 
-	gsf_property_settings_collect (GSF_OUTFILE_ZIP_TYPE,
-				       &params, &n_params,
-				       "sink", zip_parent->sink,
-				       "entry-name", name,
-				       NULL);
-	gsf_property_settings_collect_valist (GSF_OUTFILE_ZIP_TYPE,
-					      &params, &n_params,
-					      first_property_name,
-					      args);
-	if (!gsf_property_settings_find ("modtime", params, n_params))
-		gsf_property_settings_collect (GSF_OUTFILE_ZIP_TYPE,
-					       &params, &n_params,
-					       "modtime", gsf_output_get_modtime (GSF_OUTPUT (parent)),
-					       NULL);
+	gsf_prop_settings_collect (GSF_OUTFILE_ZIP_TYPE,
+				   &params, &n_params,
+				   "sink", zip_parent->sink,
+				   "entry-name", name,
+				   NULL);
+	gsf_prop_settings_collect_valist (GSF_OUTFILE_ZIP_TYPE,
+					  &params, &n_params,
+					  first_property_name,
+					  args);
+	if (!gsf_prop_settings_find ("modtime", params, n_params))
+		gsf_prop_settings_collect (GSF_OUTFILE_ZIP_TYPE,
+					   &params, &n_params,
+					   "modtime", gsf_output_get_modtime (GSF_OUTPUT (parent)),
+					   NULL);
 
-	child = (GsfOutfileZip *)g_object_newv (GSF_OUTFILE_ZIP_TYPE,
-						n_params,
-						params);
-	gsf_property_settings_free (params, n_params);
+	gsf_params_to_properties (params, n_params, &names, &values);
+
+	child = (GsfOutfileZip *)g_object_new_with_properties (GSF_OUTFILE_ZIP_TYPE,
+							       n_params,
+							       names,
+							       values);
+	gsf_prop_settings_free (params, n_params);
+	g_free (names);
+	g_free (values);
 
 	child->zip64 = zip_parent->zip64;
 	child->vdir = gsf_zip_vdir_new (name, is_dir, NULL);
@@ -1076,7 +1084,7 @@ gsf_outfile_zip_class_init (GObjectClass *gobject_class)
 				      _("Sink"),
 				      _("Where the archive is written"),
 				      GSF_OUTPUT_TYPE,
-				      GSF_PARAM_STATIC |
+				      G_PARAM_STATIC_STRINGS |
 				      G_PARAM_READWRITE |
 				      G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property
@@ -1086,7 +1094,7 @@ gsf_outfile_zip_class_init (GObjectClass *gobject_class)
 				      _("Entry Name"),
 				      _("The filename of this member in the archive without path"),
 				      NULL,
-				      GSF_PARAM_STATIC |
+				      G_PARAM_STATIC_STRINGS |
 				      G_PARAM_READWRITE |
 				      G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property
@@ -1097,7 +1105,7 @@ gsf_outfile_zip_class_init (GObjectClass *gobject_class)
 				   _("The level of compression used, zero meaning none"),
 				   0, 10,
 				   GSF_ZIP_DEFLATED,
-				   GSF_PARAM_STATIC |
+				   G_PARAM_STATIC_STRINGS |
 				   G_PARAM_READWRITE |
 				   G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property
@@ -1109,7 +1117,7 @@ gsf_outfile_zip_class_init (GObjectClass *gobject_class)
 				     "and -1 meaning the zlib default"),
 				   -1, 9,
 				   Z_DEFAULT_COMPRESSION,
-				   GSF_PARAM_STATIC |
+				   G_PARAM_STATIC_STRINGS |
 				   G_PARAM_READWRITE |
 				   G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property
@@ -1120,7 +1128,7 @@ gsf_outfile_zip_class_init (GObjectClass *gobject_class)
 				   _("Whether to use zip64 format, -1 meaning automatic"),
 				   -1, 1,
 				   ZIP_CREATE_DEFAULT_ZIP64,
-				   GSF_PARAM_STATIC |
+				   G_PARAM_STATIC_STRINGS |
 				   G_PARAM_READWRITE |
 				   G_PARAM_CONSTRUCT_ONLY));
 }
